@@ -42,6 +42,7 @@
 #ifdef HAVE_OPENBABEL2
 #if defined(HAVE_EIGEN) && defined(HAVE_AVOGADRO)
 #include "tools/moleculeview.h"
+#include <QGLFormat>
 #endif
 #include "tools/obconverter.h"
 #endif
@@ -50,24 +51,25 @@
 #include <QToolBox>
 #include <QKeyEvent>
 #include <QRegExp>
+#include <QStatusBar>
 
-#include <kmessagebox.h>
+#include <QMessageBox>
 #include <kconfigdialog.h>
 #include <kiconloader.h>
 #include <kaction.h>
 #include <kparts/part.h>
 #include <kselectaction.h>
-#include <kstatusbar.h>
-#include <kstandarddirs.h>
+
 #include <kstandardaction.h>
-#include <kicon.h>
+#include <QIcon>
 #include <kservicetypetrader.h>
-#include <kurl.h>
+#include <QUrl>
 #include <kfiledialog.h>
-#include <KLocale>
+#include <QLocale>
 #include <KPluginLoader>
-// #include <KTabWidget>
 #include <QGridLayout>
+#include <KLocalizedString>
+#include <QStandardPaths>
 
 #define IDS_ELEMENTINFO     7
 
@@ -75,9 +77,6 @@ Kalzium::Kalzium() : KXmlGuiWindow(0)
 {
     setObjectName("KalziumMainWindow");
 
-    // adding the libkdeedu catalog
-    KGlobal::locale()->insertCatalog("libkdeedu");
-
     // Init pointers with null
     m_infoDialog = 0;
     m_isotopeDialog = 0;
@@ -87,6 +86,7 @@ Kalzium::Kalzium() : KXmlGuiWindow(0)
     m_calculator = 0;
     m_exportDialog = 0;
     m_glossarydlg = 0;
+    m_elementInfo = 0;
 
     // reading the elements from file
     KalziumDataObject::instance();
@@ -172,35 +172,35 @@ void Kalzium::setupActions()
     // tools actions
     m_pPlotAction = actionCollection()->addAction("tools_plotdata");
     m_pPlotAction->setText(i18n("&Plot Data..."));
-    m_pPlotAction->setIcon(KIcon("plot"));
+    m_pPlotAction->setIcon(QIcon::fromTheme("plot"));
     connect(m_pPlotAction, SIGNAL(triggered()), this, SLOT(slotPlotData()));
 
     // calculator actions
     m_pcalculator = actionCollection()->addAction("tools_calculate");
     m_pcalculator->setText(i18n("Perform &Calculations..."));
-    m_pcalculator->setIcon(KIcon("calculate"));
+    m_pcalculator->setIcon(QIcon::fromTheme("calculate"));
     m_pcalculator->setWhatsThis(i18nc("WhatsThis Help", "This is the calculator, it performs basic chemical calculations."));
     connect(m_pcalculator, SIGNAL(triggered()), this, SLOT(showCalculator()));
 
     m_pIsotopeTableAction= actionCollection()->addAction("tools_isotopetable");
     m_pIsotopeTableAction->setText(i18n("&Isotope Table..."));
-    m_pIsotopeTableAction->setIcon(KIcon("isotopemap"));
+    m_pIsotopeTableAction->setIcon(QIcon::fromTheme("isotopemap"));
     m_pIsotopeTableAction->setWhatsThis(i18nc("WhatsThis Help", "This table shows all of the known isotopes of the chemical elements."));
     connect(m_pIsotopeTableAction, SIGNAL(triggered()), this, SLOT(slotIsotopeTable()));
 
     m_pGlossaryAction = actionCollection()->addAction("tools_glossary");
     m_pGlossaryAction->setText(i18n("&Glossary..."));
-    m_pGlossaryAction->setIcon(KIcon("glossary"));
+    m_pGlossaryAction->setIcon(QIcon::fromTheme("glossary"));
     connect(m_pGlossaryAction, SIGNAL(triggered()), this, SLOT(slotGlossary()));
 
     m_pRSAction = actionCollection()->addAction("tools_rs");
     m_pRSAction->setText(i18n("&R/S Phrases..."));
-    m_pRSAction->setIcon(KIcon("kalzium_rs"));
+    m_pRSAction->setIcon(QIcon::fromTheme("kalzium_rs"));
     connect(m_pRSAction, SIGNAL(triggered()), this, SLOT(slotRS()));
 
     m_pOBConverterAction = actionCollection()->addAction("tools_obconverter");
     m_pOBConverterAction->setText(i18n("Convert chemical files..."));
-    m_pOBConverterAction->setIcon(KIcon("edit-copy"));
+    m_pOBConverterAction->setIcon(QIcon::fromTheme("edit-copy"));
     m_pOBConverterAction->setWhatsThis(i18nc("WhatsThis Help", "With this tool, you can convert files containing chemical data between various file formats."));
     connect(m_pOBConverterAction, SIGNAL(triggered()), this, SLOT(slotOBConverter()));
 #ifndef HAVE_OPENBABEL2
@@ -209,7 +209,7 @@ void Kalzium::setupActions()
 
     m_pMoleculesviewer = actionCollection()->addAction("tools_moleculeviewer");
     m_pMoleculesviewer->setText(i18n("Molecular Editor..."));
-    m_pMoleculesviewer->setIcon(KIcon("kalzium_molviewer"));
+    m_pMoleculesviewer->setIcon(QIcon::fromTheme("kalzium_molviewer"));
     m_pMoleculesviewer->setWhatsThis(i18nc("WhatsThis Help", "This tool allows you to view and edit 3D molecular structures."));
     connect(m_pMoleculesviewer, SIGNAL(triggered()), this, SLOT(slotMoleculeviewer()));
 #if !defined(HAVE_OPENBABEL2) || !defined(HAVE_EIGEN) || !defined(HAVE_AVOGADRO)
@@ -218,7 +218,7 @@ void Kalzium::setupActions()
 
     m_pTables = actionCollection()->addAction("tools_tables");
     m_pTables->setText(i18n("&Tables..."));
-    m_pTables->setIcon(KIcon("kalzium_tables"));
+    m_pTables->setIcon(QIcon::fromTheme("kalzium_tables"));
     m_pTables->setWhatsThis(i18nc("WhatsThis Help", "This will open a dialog with listings of symbols and numbers related to chemistry."));
 
     connect(m_pTables, SIGNAL(triggered()), this, SLOT(slotTables()));
@@ -226,17 +226,17 @@ void Kalzium::setupActions()
     // other period view options
     m_pLegendAction = m_legendDock->toggleViewAction();
     actionCollection()->addAction("view_legend", m_pLegendAction);
-    m_pLegendAction->setIcon(KIcon("legend"));
+    m_pLegendAction->setIcon(QIcon::fromTheme("legend"));
     m_pLegendAction->setWhatsThis(i18nc("WhatsThis Help", "This will show or hide the legend for the periodic table."));
 
     m_SidebarAction = m_dockWin->toggleViewAction();
     actionCollection()->addAction("view_sidebar", m_SidebarAction);
-    m_SidebarAction->setIcon(KIcon("sidebar"));
+    m_SidebarAction->setIcon(QIcon::fromTheme("sidebar"));
     m_SidebarAction->setWhatsThis(i18nc("WhatsThis Help", "This will show or hide a sidebar with additional information and a set of tools."));
 
     m_SidebarAction = m_tableDock->toggleViewAction();
     actionCollection()->addAction("view_tablebar", m_SidebarAction);
-    m_SidebarAction->setIcon(KIcon("kalzium_tables"));
+    m_SidebarAction->setIcon(QIcon::fromTheme("kalzium_tables"));
     m_SidebarAction->setWhatsThis(i18nc("WhatsThis Help", "This will show or hide a sidebar with additional information about the table."));
 
     // the standard actions
@@ -244,7 +244,7 @@ void Kalzium::setupActions()
 
     KStandardAction::preferences(this, SLOT(showSettingsDialog()), actionCollection());
 
-    actionCollection()->addAction("quit", KStandardAction::quit(kapp, SLOT(closeAllWindows()), actionCollection()));
+    actionCollection()->addAction("quit", KStandardAction::quit(qApp, SLOT(quit()), actionCollection()));
 
     m_legendWidget->LockWidget();
 
@@ -299,7 +299,7 @@ void Kalzium::setupSidebars()
     m_detailWidget->setObjectName("DetailedGraphicalOverview");
     m_detailWidget->setMinimumSize(200, m_detailWidget->minimumSize().height());
 
-    m_toolbox->addItem(m_detailWidget, KIcon("overview"), i18n("Overview"));
+    m_toolbox->addItem(m_detailWidget, QIcon::fromTheme("overview"), i18n("Overview"));
 
     m_gradientWidget = new GradientWidgetImpl(m_toolbox);
     m_gradientWidget->setObjectName("viewtWidget");
@@ -311,7 +311,7 @@ void Kalzium::setupSidebars()
     connect(m_gradientWidget->gradient_combo, SIGNAL(currentIndexChanged(int)),
              this, SLOT(slotSwitchtoLookGradient(int)));
 
-    m_toolbox->addItem(m_gradientWidget, KIcon("statematter"), i18n("View"));
+    m_toolbox->addItem(m_gradientWidget, QIcon::fromTheme("statematter"), i18n("View"));
 
     addDockWidget(Qt::LeftDockWidgetArea, m_dockWin);
     addDockWidget(Qt::BottomDockWidgetArea, m_tableDock, Qt::Horizontal);
@@ -322,7 +322,7 @@ void Kalzium::setupSidebars()
 
 void Kalzium::slotExportTable()
 {
-    QString fileName = KFileDialog::getSaveFileName(QString(), i18n("*.png *.xpm *.jpg *.svg"), //
+    QString fileName = KFileDialog::getSaveFileName(QUrl(), i18n("*.png *.xpm *.jpg *.svg"), //
                        this,
                        i18n("Save Kalzium's Table In"));
 
@@ -340,15 +340,16 @@ void Kalzium::slotGlossary()
       // creating the glossary dialog and loading the glossaries we have
       m_glossarydlg = new GlossaryDialog(this);
       m_glossarydlg->setObjectName(QLatin1String("glossary"));
-      QString dir = KGlobal::dirs()->findResourceDir("data", "kalzium/data/");
-      QString picturepath = dir + "kalzium/data/bg.jpg";
-      KUrl u = KUrl::fromPath(dir + "kalzium/data/knowledge.xml");
+      QString dir = QStandardPaths::locate(QStandardPaths::DataLocation, "data/", QStandardPaths::LocateDirectory);
+      dir = QFileInfo(dir).absolutePath();
+      QString picturepath = dir + "/bg.jpg";
+      QUrl u = QUrl::fromLocalFile(dir + "/knowledge.xml");
       Glossary *g = new Glossary(u);
       g->setName(i18n("Knowledge"));
       g->setBackgroundPicture(picturepath);
       m_glossarydlg->addGlossary(g, true);
-      u = KUrl::fromPath(dir + "kalzium/data/tools.xml");
-      g = new Glossary(u, dir + "kalzium/data/toolpics/");
+      u = QUrl::fromLocalFile(dir + "/tools.xml");
+      g = new Glossary(u, dir + "/toolpics/");
       g->setName(i18n("Tools"));
       g->setBackgroundPicture(picturepath);
       m_glossarydlg->addGlossary(g, true);
@@ -379,7 +380,7 @@ MoleculeDialog *Kalzium::slotMoleculeviewer()
 #if defined(HAVE_OPENBABEL2) && defined(HAVE_EIGEN) && defined(HAVE_AVOGADRO)
 
     if (!QGLFormat::hasOpenGL()) {
-        KMessageBox::error(0, i18n("This system does not support OpenGL."), i18n("Kalzium Error"));
+        QMessageBox::critical(Q_NULLPTR, i18n("Kalzium Error"), i18n("This system does not support OpenGL."));
         return NULL;
     }
 
@@ -443,19 +444,19 @@ void Kalzium::slotSwitchtoTable(int index)
         m_infoDialog->setTableType(m_periodicTable->table());
     }
     Prefs::setTable(index);
-    Prefs::self()->writeConfig();
+    Prefs::self()->save();
 }
 
 void Kalzium::slotSwitchtoNumeration(int index)
 {
     emit numerationChanged(index);
     Prefs::setNumeration(index);
-    Prefs::self()->writeConfig();
+    Prefs::self()->save();
 }
 
 void Kalzium::slotSwitchtoLookGradient(int which)
 {
-    kDebug() << "slotSwitchtoLookGradient Kalzium";
+    qDebug() << "slotSwitchtoLookGradient Kalzium";
 
     KalziumElementProperty::instance()->setGradient(which);
 
@@ -475,7 +476,7 @@ void Kalzium::slotSwitchtoLookGradient(int which)
 
 void Kalzium::slotSwitchtoLookScheme(int which)
 {
-    kDebug() << "slotSwitchtoLookScheme Kalzium";
+    qDebug() << "slotSwitchtoLookScheme Kalzium";
 
     KalziumElementProperty::instance()->setScheme(which);
 
@@ -538,7 +539,7 @@ void Kalzium::slotUpdateSettings()
 
     Prefs::setTemperatureUnit(m_unitsDialog->getTemperatureUnitId());
 
-    Prefs::self()->writeConfig();
+    Prefs::self()->save();
 
     /*This slot function calls change the color of pse elements immideately after prefs change*/
     slotSwitchtoLookGradient(Prefs::colorgradientbox());
@@ -555,23 +556,24 @@ void Kalzium::slotShowExportDialog()
 
 void Kalzium::setupStatusBar()
 {
-    statusBar()->insertItem("", 0, 0);
-    statusBar()->setItemAlignment(0, Qt::AlignRight);
+    QStatusBar *statusBar = new QStatusBar(this);
+    setStatusBar(statusBar);
 
-    statusBar()->insertItem("", IDS_ELEMENTINFO, 1);
-    statusBar()->setItemAlignment(IDS_ELEMENTINFO, Qt::AlignRight);
-    statusBar()->show();
+    m_elementInfo = new QLabel("");
+    m_elementInfo->setAlignment(Qt::AlignRight);
+    statusBar->addWidget(m_elementInfo, 1);
+    statusBar->show();
 }
 
 void Kalzium::elementHover(int num)
 {
     //     extractIconicInformationAboutElement(num);
-
     Element *e = KalziumDataObject::instance()->element(num);
-    statusBar()->changeItem(i18nc("For example: \"Carbon (6), Mass: 12.0107 u\"", "%1 (%2), Mass: %3 u",
-                                    e->dataAsString(ChemicalDataObject::name),
-                                    e->dataAsString(ChemicalDataObject::atomicNumber),
-                                    e->dataAsString(ChemicalDataObject::mass)), IDS_ELEMENTINFO);
+    m_elementInfo->setText(i18nc("For example: \"Carbon (6), Mass: 12.0107 u\"", "%1 (%2), Mass: %3 u",
+                                 e->dataAsString(ChemicalDataObject::name),
+                                 e->dataAsString(ChemicalDataObject::atomicNumber),
+                                 e->dataAsString(ChemicalDataObject::mass)));
+    qDebug() << "change item in status bar";
 
     m_detailWidget->setElement(num);
 }
@@ -580,7 +582,8 @@ void Kalzium::elementHover(int num)
 void Kalzium::extractIconicInformationAboutElement(int elementNumber)
 {
     QString setname = "school";
-    QString pathname = KGlobal::dirs()->findResourceDir("appdata", "data/iconsets/") + "data/iconsets/";
+    QString pathname = QStandardPaths::locate(QStandardPaths::DataLocation, "data/iconsets/", QStandardPaths::LocateDirectory);
+    pathname = QFileInfo(pathname).absolutePath();
     QString filename = pathname + setname + '/' + "iconinformation.txt";
 
     QFile file(filename);
@@ -610,8 +613,6 @@ void Kalzium::openInformationDialog(int number)
         m_infoDialog = new DetailedInfoDlg(number, this);
 
         // Remove the selection when this dialog finishes or hides.
-        connect(m_infoDialog, SIGNAL(hidden()),
-                m_periodicTable, SLOT(slotUnSelectElements()));
         connect(m_infoDialog, SIGNAL(elementChanged(int)),
                 m_periodicTable, SLOT(slotSelectOneElement(int)));
         connect(m_infoDialog, SIGNAL(elementChanged(int)),
@@ -651,4 +652,3 @@ QSize Kalzium::sizeHint() const
     return QSize(700, 500);
 }
 
-#include "kalzium.moc"
